fnss.topologies.parsers.parse_topology_zoo — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_topology_zoo

`parse_topology_zoo`(path)

  Parse a topology from the Topology Zoo dataset.

  Note: if the topology to be parsed contains multilinks, i.e. multiple links between the same pair or nodes, the parsing may fail or not parse only one link.

  Parameters : | path : str The path to the Topology Zoo file
  Returns : | topology : Topology or DirectedTopology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »